@@ -47,8 +47,9 @@ class VideoSettings:
 
     def _get_quality_settings(self):
         if self.hw_accel == "nvidia":
-            # nvenc doesn't support CRF; only CQ mode
-            output = f" -cq {self.quality}"
+            # nvenc doesn't support CRF; only CQ and QP modes. QP consistently provides better quality output for the same bitrate on NVENC however, so we're using that
+            output = f" -rc constqp -qp {self.quality}"
+            output += " -b:v 0"  # Unless bitrate is set to 0, CQ is mostly ignored
             # output += f" -rc-lookahead -b_ref_mode middle" # b-frames are disabled by default, and only supported on Turing+ architectures. Need to auto-detect this
         else:
             output = f" -crf {self.quality}"
